@@ -127,12 +127,9 @@ sub work {
 
         while (my ($devid, $util) = each %$stats) {
             # Lets not propagate devices that we accidentally find.
-            # This does hit the DB every time a device does not exist, so
-            # perhaps should add negative caching in the future.
-            $self->{devutil}->{cur}->{$devid} = $util;
             my $dev = Mgd::device_factory()->get_by_id($devid);
             next unless $dev;
-            $dev->set_observed_utilization($util);
+            $self->{devutil}->{cur}->{$devid} = $util;
         }
     });
 
