@@ -202,8 +202,7 @@ sub cmd_create_open {
     my $args = shift;
 
     # has to be filled out for some plugins
-    $args->{dmid} = $self->check_domain($args)
-        or return $self->err_line('domain_not_found');
+    $args->{dmid} = $self->check_domain($args) or return;
 
     # first, pass this to a hook to do any manipulations needed
     eval {MogileFS::run_global_hook('cmd_create_open', $args)};
@@ -249,16 +248,15 @@ sub cmd_create_open {
 
     $profstart->("find_deviceid");
 
-    my @devices;
-
-    unless (MogileFS::run_global_hook('cmd_create_open_order_devices', [Mgd::device_factory()->get_all], \@devices)) {
-        @devices = sort_devs_by_freespace(Mgd::device_factory()->get_all);
-    }
-
+    my @devices = Mgd::device_factory()->get_all;
     if ($size) {
         @devices = grep { ($_->mb_free * 1024*1024) > $size } @devices;
     }
 
+    unless (MogileFS::run_global_hook('cmd_create_open_order_devices', [ @devices ], \@devices)) {
+        @devices = sort_devs_by_freespace(@devices);
+    }
+
     # find suitable device(s) to put this file on.
     my @dests; # MogileFS::Device objects which are suitable
 
@@ -357,8 +355,7 @@ sub cmd_create_close {
     my $args = shift;
 
     # has to be filled out for some plugins
-    $args->{dmid} = $self->check_domain($args)
-        or return $self->err_line('domain_not_found');
+    $args->{dmid} = $self->check_domain($args) or return;
 
     # call out to a hook that might modify the arguments for us
     MogileFS::run_global_hook('cmd_create_close', $args);
@@ -488,8 +485,7 @@ sub cmd_updateclass {
     my MogileFS::Worker::Query $self = shift;
     my $args = shift;
 
-    $args->{dmid} = $self->check_domain($args)
-        or return $self->err_line('domain_not_found');
+    $args->{dmid} = $self->check_domain($args) or return;
 
     # call out to a hook that might modify the arguments for us, abort if it tells us to
     my $rv = MogileFS::run_global_hook('cmd_updateclass', $args);
@@ -523,8 +519,7 @@ sub cmd_delete {
     my $args = shift;
 
     # validate domain for plugins
-    $args->{dmid} = $self->check_domain($args)
-        or return $self->err_line('domain_not_found');
+    $args->{dmid} = $self->check_domain($args) or return;
 
     # now invoke the plugin, abort if it tells us to
     my $rv = MogileFS::run_global_hook('cmd_delete', $args);
@@ -563,8 +558,7 @@ sub cmd_file_debug {
         $fid = $sto->file_row_from_fidid($args->{fid}+0);
     } else {
         # If not, require dmid/dkey and pick up the fid from there.
-        $args->{dmid} = $self->check_domain($args)
-            or return $self->err_line('domain_not_found');
+        $args->{dmid} = $self->check_domain($args) or return;
         return $self->err_line("no_key") unless valid_key($args->{key});
         
         # now invoke the plugin, abort if it tells us to
@@ -629,8 +623,7 @@ sub cmd_file_info {
     my $args = shift;
 
     # validate domain for plugins
-    $args->{dmid} = $self->check_domain($args)
-        or return $self->err_line('domain_not_found');
+    $args->{dmid} = $self->check_domain($args) or return;
 
     # now invoke the plugin, abort if it tells us to
     my $rv = MogileFS::run_global_hook('cmd_file_info', $args);
@@ -716,8 +709,7 @@ sub cmd_list_keys {
     my $args = shift;
 
     # validate parameters
-    my $dmid = $self->check_domain($args)
-        or return $self->err_line('domain_not_found');
+    my $dmid = $self->check_domain($args) or return;
     my ($prefix, $after, $limit) = ($args->{prefix}, $args->{after}, $args->{limit});
 
     if (defined $prefix and $prefix ne '') {
@@ -758,8 +750,7 @@ sub cmd_rename {
     my $args = shift;
 
     # validate parameters
-    my $dmid = $self->check_domain($args)
-        or return $self->err_line('domain_not_found');
+    my $dmid = $self->check_domain($args) or return;
     my ($fkey, $tkey) = ($args->{from_key}, $args->{to_key});
     unless (valid_key($fkey) && valid_key($tkey)) {
         return $self->err_line("no_key");
@@ -1089,8 +1080,7 @@ sub cmd_get_paths {
     my $memcache_ttl  = MogileFS::Config->server_setting_cached("memcache_ttl") || 3600;
 
     # validate domain for plugins
-    $args->{dmid} = $self->check_domain($args)
-        or return $self->err_line('domain_not_found');
+    $args->{dmid} = $self->check_domain($args) or return;
 
     # now invoke the plugin, abort if it tells us to
     my $rv = MogileFS::run_global_hook('cmd_get_paths', $args);
@@ -1268,8 +1258,7 @@ sub cmd_edit_file {
     my $memc = MogileFS::Config->memcache_client;
 
     # validate domain for plugins
-    $args->{dmid} = $self->check_domain($args)
-        or return $self->err_line('domain_not_found');
+    $args->{dmid} = $self->check_domain($args) or return;
 
     # now invoke the plugin, abort if it tells us to
     my $rv = MogileFS::run_global_hook('cmd_get_paths', $args);
@@ -1519,7 +1508,7 @@ sub cmd_fsck_start {
     my $final_fid   = $intss->("fsck_fid_at_end");
     if (($checked_fid && $final_fid && $checked_fid >= $final_fid) ||
         (!$final_fid && !$checked_fid)) {
-        $self->_do_fsck_reset or return $self->err_line;
+        $self->_do_fsck_reset or return $self->err_line("db");
     }
 
     # set params for stats:
@@ -1555,27 +1544,34 @@ sub cmd_fsck_reset {
     $sto->set_server_setting("fsck_highest_fid_checked", 
         ($args->{startpos} ? $args->{startpos} : "0"));
 
-    $self->_do_fsck_reset or return $self->err_line;
+    $self->_do_fsck_reset or return $self->err_line("db");
     return $self->ok_line;
 }
 
 sub _do_fsck_reset {
     my MogileFS::Worker::Query $self = shift;
-    my $sto = Mgd::get_store();
-    $sto->set_server_setting("fsck_start_time",       undef);
-    $sto->set_server_setting("fsck_stop_time",        undef);
-    $sto->set_server_setting("fsck_fids_checked",     0);
-    $sto->set_server_setting("fsck_fid_at_end",       $sto->max_fidid);
+    eval {
+        my $sto = Mgd::get_store();
+        $sto->set_server_setting("fsck_start_time",       undef);
+        $sto->set_server_setting("fsck_stop_time",        undef);
+        $sto->set_server_setting("fsck_fids_checked",     0);
+        $sto->set_server_setting("fsck_fid_at_end",       $sto->max_fidid);
 
-    # clear existing event counts summaries.
-    my $ss = $sto->server_settings;
-    foreach my $k (keys %$ss) {
-        next unless $k =~ /^fsck_sum_evcount_/;
-        $sto->set_server_setting($k, undef);
+        # clear existing event counts summaries.
+        my $ss = $sto->server_settings;
+        foreach my $k (keys %$ss) {
+            next unless $k =~ /^fsck_sum_evcount_/;
+            $sto->set_server_setting($k, undef);
+        }
+        my $logid = $sto->max_fsck_logid;
+        $sto->set_server_setting("fsck_start_maxlogid", $logid);
+        $sto->set_server_setting("fsck_logid_processed", $logid);
+    };
+    if ($@) {
+        error("DB error in _do_fsck_reset: $@");
+        return 0;
     }
-    my $logid = $sto->max_fsck_logid;
-    $sto->set_server_setting("fsck_start_maxlogid", $logid);
-    $sto->set_server_setting("fsck_logid_processed", $logid);
+    return 1;
 }
 
 sub cmd_fsck_clearlog {
@@ -1807,6 +1803,7 @@ sub err_line {
         $self->{querystarttime} = undef;
     } else {
         # don't send another ERR line if we already sent one
+        error("err_line called redundantly with $err_code ( " . eurl($err_text) . ")");
         return 0;
     }
 
